CastTextTrack class

Constructors

CastTextTrack({required int trackId, required String url, required String language, String? name, String contentType = 'text/vtt'})
const

Properties

contentType String
final
hashCode int
The hash code for this object.
no setterinherited
language String
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackId int
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited