Warms the opt-in Android disk cache (NativeVideoPlayerConfig.androidEnableDiskCache) for upcoming videos.
NativeVideoPlayerConfig.global = const NativeVideoPlayerConfig(
androidEnableDiskCache: true,
);
// Later, e.g. when the next feed items become known:
await NativeVideoPlayerCache.precache(nextItem.videoUrl);
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited