CastSession class

Properties

device CastDevice
final
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status CastSessionStatus
no setter
statusStream Stream<CastSessionStatus>
no setter

Methods

close() Future<void>
loadMedia({required String contentUrl, String contentType = 'video/mp4', String streamType = 'BUFFERED', String? title, String? subtitle, String? imageUrl, List<CastTextTrack> textTracks = const <CastTextTrack>[], List<int> activeTrackIds = const <int>[], bool autoplay = true, Duration startAt = Duration.zero}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<void>
play() Future<void>
requestStatus() Future<void>
seek(Duration position) Future<void>
setActiveTracks(List<int> trackIds) Future<void>
setLooping(bool looping) → void
setMuted(bool muted) Future<void>
setVolume(double level) Future<void>
stop() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

connect(CastDevice device, {Duration timeout = const Duration(seconds: 10)}) Future<CastSession>